embassy-stm32

Crates

git

Versions

stm32f302cb

Flavors

TSC

Struct TSC 

pub struct TSC { /* private fields */ }
TSC peripheral

Implementations

Source

impl TSC

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that youโ€™re only using one instance of this type at a time.